# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"test_fail": "00_test.ipynb",
         "test": "00_test.ipynb",
         "nequals": "00_test.ipynb",
         "test_eq": "00_test.ipynb",
         "test_eq_type": "00_test.ipynb",
         "test_ne": "00_test.ipynb",
         "is_close": "00_test.ipynb",
         "test_close": "00_test.ipynb",
         "test_is": "00_test.ipynb",
         "test_shuffled": "00_test.ipynb",
         "test_stdout": "00_test.ipynb",
         "test_warns": "00_test.ipynb",
         "TEST_IMAGE": "00_test.ipynb",
         "TEST_IMAGE_BW": "00_test.ipynb",
         "test_fig_exists": "00_test.ipynb",
         "ExceptionExpected": "00_test.ipynb",
         "exception": "00_test.ipynb",
         "defaults": "01_basics.ipynb",
         "ifnone": "01_basics.ipynb",
         "maybe_attr": "01_basics.ipynb",
         "basic_repr": "01_basics.ipynb",
         "is_array": "01_basics.ipynb",
         "listify": "01_basics.ipynb",
         "tuplify": "01_basics.ipynb",
         "true": "01_basics.ipynb",
         "NullType": "01_basics.ipynb",
         "null": "01_basics.ipynb",
         "tonull": "01_basics.ipynb",
         "get_class": "01_basics.ipynb",
         "mk_class": "01_basics.ipynb",
         "wrap_class": "01_basics.ipynb",
         "ignore_exceptions": "01_basics.ipynb",
         "exec_local": "01_basics.ipynb",
         "risinstance": "01_basics.ipynb",
         "Inf": "01_basics.ipynb",
         "in_": "01_basics.ipynb",
         "operator.in_": "01_basics.ipynb",
         "stop": "01_basics.ipynb",
         "gen": "01_basics.ipynb",
         "chunked": "01_basics.ipynb",
         "otherwise": "01_basics.ipynb",
         "custom_dir": "01_basics.ipynb",
         "AttrDict": "01_basics.ipynb",
         "get_annotations_ex": "01_basics.ipynb",
         "eval_type": "01_basics.ipynb",
         "type_hints": "01_basics.ipynb",
         "annotations": "01_basics.ipynb",
         "anno_ret": "01_basics.ipynb",
         "union2tuple": "01_basics.ipynb",
         "argnames": "01_basics.ipynb",
         "with_cast": "01_basics.ipynb",
         "store_attr": "01_basics.ipynb",
         "attrdict": "01_basics.ipynb",
         "properties": "01_basics.ipynb",
         "camel2words": "01_basics.ipynb",
         "camel2snake": "01_basics.ipynb",
         "snake2camel": "01_basics.ipynb",
         "class2attr": "01_basics.ipynb",
         "getcallable": "01_basics.ipynb",
         "getattrs": "01_basics.ipynb",
         "hasattrs": "01_basics.ipynb",
         "setattrs": "01_basics.ipynb",
         "try_attrs": "01_basics.ipynb",
         "GetAttrBase": "01_basics.ipynb",
         "GetAttr": "01_basics.ipynb",
         "delegate_attr": "01_basics.ipynb",
         "ShowPrint": "01_basics.ipynb",
         "Int": "01_basics.ipynb",
         "Str": "01_basics.ipynb",
         "Float": "01_basics.ipynb",
         "flatten": "01_basics.ipynb",
         "concat": "01_basics.ipynb",
         "strcat": "01_basics.ipynb",
         "detuplify": "01_basics.ipynb",
         "replicate": "01_basics.ipynb",
         "setify": "01_basics.ipynb",
         "merge": "01_basics.ipynb",
         "range_of": "01_basics.ipynb",
         "groupby": "01_basics.ipynb",
         "last_index": "01_basics.ipynb",
         "filter_dict": "01_basics.ipynb",
         "filter_keys": "01_basics.ipynb",
         "filter_values": "01_basics.ipynb",
         "cycle": "02_foundation.ipynb",
         "zip_cycle": "02_foundation.ipynb",
         "sorted_ex": "01_basics.ipynb",
         "not_": "01_basics.ipynb",
         "argwhere": "01_basics.ipynb",
         "filter_ex": "01_basics.ipynb",
         "renumerate": "01_basics.ipynb",
         "first": "01_basics.ipynb",
         "nested_attr": "01_basics.ipynb",
         "nested_callable": "01_basics.ipynb",
         "nested_idx": "01_basics.ipynb",
         "set_nested_idx": "01_basics.ipynb",
         "val2idx": "01_basics.ipynb",
         "uniqueify": "01_basics.ipynb",
         "loop_first_last": "01_basics.ipynb",
         "loop_first": "01_basics.ipynb",
         "loop_last": "01_basics.ipynb",
         "num_methods": "01_basics.ipynb",
         "rnum_methods": "01_basics.ipynb",
         "inum_methods": "01_basics.ipynb",
         "fastuple": "01_basics.ipynb",
         "arg0": "01_basics.ipynb",
         "arg1": "01_basics.ipynb",
         "arg2": "01_basics.ipynb",
         "arg3": "01_basics.ipynb",
         "arg4": "01_basics.ipynb",
         "bind": "01_basics.ipynb",
         "mapt": "01_basics.ipynb",
         "map_ex": "01_basics.ipynb",
         "compose": "01_basics.ipynb",
         "maps": "01_basics.ipynb",
         "partialler": "01_basics.ipynb",
         "instantiate": "01_basics.ipynb",
         "using_attr": "01_basics.ipynb",
         "Self": "01_basics.ipynb",
         "copy_func": "01_basics.ipynb",
         "patch_to": "01_basics.ipynb",
         "patch": "01_basics.ipynb",
         "patch_property": "01_basics.ipynb",
         "compile_re": "01_basics.ipynb",
         "ImportEnum": "01_basics.ipynb",
         "StrEnum": "01_basics.ipynb",
         "str_enum": "01_basics.ipynb",
         "Stateful": "01_basics.ipynb",
         "PrettyString": "01_basics.ipynb",
         "even_mults": "01_basics.ipynb",
         "num_cpus": "01_basics.ipynb",
         "defaults.cpus": "01_basics.ipynb",
         "add_props": "01_basics.ipynb",
         "typed": "01_basics.ipynb",
         "exec_new": "01_basics.ipynb",
         "exec_import": "01_basics.ipynb",
         "working_directory": "02_foundation.ipynb",
         "add_docs": "02_foundation.ipynb",
         "docs": "02_foundation.ipynb",
         "coll_repr": "02_foundation.ipynb",
         "is_bool": "02_foundation.ipynb",
         "mask2idxs": "02_foundation.ipynb",
         "is_indexer": "02_foundation.ipynb",
         "CollBase": "02_foundation.ipynb",
         "L": "02_foundation.ipynb",
         "L.__signature__": "02_foundation.ipynb",
         "save_config_file": "02_foundation.ipynb",
         "read_config_file": "02_foundation.ipynb",
         "Config": "02_foundation.ipynb",
         "walk": "03_xtras.ipynb",
         "globtastic": "03_xtras.ipynb",
         "maybe_open": "03_xtras.ipynb",
         "image_size": "03_xtras.ipynb",
         "bunzip": "03_xtras.ipynb",
         "loads": "03_xtras.ipynb",
         "loads_multi": "03_xtras.ipynb",
         "dumps": "03_xtras.ipynb",
         "untar_dir": "03_xtras.ipynb",
         "repo_details": "03_xtras.ipynb",
         "run": "03_xtras.ipynb",
         "open_file": "03_xtras.ipynb",
         "save_pickle": "03_xtras.ipynb",
         "load_pickle": "03_xtras.ipynb",
         "dict2obj": "03_xtras.ipynb",
         "obj2dict": "03_xtras.ipynb",
         "repr_dict": "03_xtras.ipynb",
         "is_listy": "03_xtras.ipynb",
         "mapped": "03_xtras.ipynb",
         "Path.readlines": "03_xtras.ipynb",
         "Path.read_json": "03_xtras.ipynb",
         "Path.mk_write": "03_xtras.ipynb",
         "Path.relpath": "03_xtras.ipynb",
         "Path.ls": "03_xtras.ipynb",
         "Path.__repr__": "03_xtras.ipynb",
         "Path.delete": "03_xtras.ipynb",
         "IterLen": "03_xtras.ipynb",
         "ReindexCollection": "03_xtras.ipynb",
         "get_source_link": "03_xtras.ipynb",
         "truncstr": "03_xtras.ipynb",
         "spark_chars": "03_xtras.ipynb",
         "sparkline": "03_xtras.ipynb",
         "modify_exception": "03_xtras.ipynb",
         "round_multiple": "03_xtras.ipynb",
         "str2bool": "03_xtras.ipynb",
         "set_num_threads": "03_xtras.ipynb",
         "join_path_file": "03_xtras.ipynb",
         "autostart": "03_xtras.ipynb",
         "EventTimer": "03_xtras.ipynb",
         "stringfmt_names": "03_xtras.ipynb",
         "PartialFormatter": "03_xtras.ipynb",
         "partial_format": "03_xtras.ipynb",
         "utc2local": "03_xtras.ipynb",
         "local2utc": "03_xtras.ipynb",
         "trace": "03_xtras.ipynb",
         "modified_env": "03_xtras.ipynb",
         "ContextManagers": "03_xtras.ipynb",
         "shufflish": "03_xtras.ipynb",
         "threaded": "03a_parallel.ipynb",
         "startthread": "03a_parallel.ipynb",
         "parallelable": "03a_parallel.ipynb",
         "ThreadPoolExecutor": "03a_parallel.ipynb",
         "ProcessPoolExecutor": "03a_parallel.ipynb",
         "parallel": "03a_parallel.ipynb",
         "add_one": "03a_parallel.ipynb",
         "run_procs": "03a_parallel.ipynb",
         "parallel_gen": "03a_parallel.ipynb",
         "url_default_headers": "03b_net.ipynb",
         "urlquote": "03b_net.ipynb",
         "urlwrap": "03b_net.ipynb",
         "ExceptionsHTTP": "03b_net.ipynb",
         "HTTP4xxClientError": "03b_net.ipynb",
         "HTTP5xxServerError": "03b_net.ipynb",
         "urlopen": "03b_net.ipynb",
         "urlread": "03b_net.ipynb",
         "urljson": "03b_net.ipynb",
         "urlcheck": "03b_net.ipynb",
         "urlclean": "03b_net.ipynb",
         "urlretrieve": "03b_net.ipynb",
         "urldest": "03b_net.ipynb",
         "urlsave": "03b_net.ipynb",
         "urlvalid": "03b_net.ipynb",
         "urlrequest": "03b_net.ipynb",
         "Request.summary": "03b_net.ipynb",
         "urlsend": "03b_net.ipynb",
         "do_request": "03b_net.ipynb",
         "start_server": "03b_net.ipynb",
         "start_client": "03b_net.ipynb",
         "lenient_issubclass": "04_dispatch.ipynb",
         "sorted_topologically": "04_dispatch.ipynb",
         "TypeDispatch": "04_dispatch.ipynb",
         "DispatchReg": "04_dispatch.ipynb",
         "typedispatch": "04_dispatch.ipynb",
         "retain_meta": "04_dispatch.ipynb",
         "default_set_meta": "04_dispatch.ipynb",
         "retain_type": "04_dispatch.ipynb",
         "retain_types": "04_dispatch.ipynb",
         "explode_types": "04_dispatch.ipynb",
         "Transform": "05_transform.ipynb",
         "InplaceTransform": "05_transform.ipynb",
         "DisplayedTransform": "05_transform.ipynb",
         "ItemTransform": "05_transform.ipynb",
         "get_func": "05_transform.ipynb",
         "Func": "05_transform.ipynb",
         "Sig": "05_transform.ipynb",
         "compose_tfms": "05_transform.ipynb",
         "mk_transform": "05_transform.ipynb",
         "gather_attrs": "05_transform.ipynb",
         "gather_attr_names": "05_transform.ipynb",
         "Pipeline": "05_transform.ipynb",
         "docstring": "06_docments.ipynb",
         "parse_docstring": "06_docments.ipynb",
         "isdataclass": "06_docments.ipynb",
         "get_dataclass_source": "06_docments.ipynb",
         "get_source": "06_docments.ipynb",
         "empty": "06_docments.ipynb",
         "get_name": "06_docments.ipynb",
         "qual_name": "06_docments.ipynb",
         "docments": "06_docments.ipynb",
         "test_sig": "07_meta.ipynb",
         "FixSigMeta": "07_meta.ipynb",
         "PrePostInitMeta": "07_meta.ipynb",
         "AutoInit": "07_meta.ipynb",
         "NewChkMeta": "07_meta.ipynb",
         "BypassNewMeta": "07_meta.ipynb",
         "empty2none": "07_meta.ipynb",
         "anno_dict": "07_meta.ipynb",
         "use_kwargs_dict": "07_meta.ipynb",
         "use_kwargs": "07_meta.ipynb",
         "delegates": "07_meta.ipynb",
         "method": "07_meta.ipynb",
         "funcs_kwargs": "07_meta.ipynb",
         "store_true": "08_script.ipynb",
         "store_false": "08_script.ipynb",
         "bool_arg": "08_script.ipynb",
         "clean_type_str": "08_script.ipynb",
         "Param": "08_script.ipynb",
         "anno_parser": "08_script.ipynb",
         "args_from_prog": "08_script.ipynb",
         "SCRIPT_INFO": "08_script.ipynb",
         "call_parse": "08_script.ipynb"}

modules = ["test.py",
           "basics.py",
           "foundation.py",
           "xtras.py",
           "parallel.py",
           "net.py",
           "dispatch.py",
           "transform.py",
           "docments.py",
           "meta.py",
           "script.py"]

doc_url = "https://fastcore.fast.ai/"

git_url = "https://github.com/fastai/fastcore/tree/master/"

def custom_doc_links(name):
    from nbdev.showdoc import try_external_doc_link
    return try_external_doc_link(name, ['fastai', 'nbdev'])
