# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/',
                'doc_host': 'https://fastcore.fast.ai',
                'git_url': 'https://github.com/fastai/fastcore/',
                'lib_path': 'fastcore'},
  'syms': { 'fastcore.all': {},
            'fastcore.basics': { 'fastcore.basics.AttrDict': ('basics.html#attrdict', 'fastcore/basics.py'),
                                 'fastcore.basics.AttrDict.__dir__': ('basics.html#attrdict.__dir__', 'fastcore/basics.py'),
                                 'fastcore.basics.AttrDict.__getattr__': ('basics.html#attrdict.__getattr__', 'fastcore/basics.py'),
                                 'fastcore.basics.AttrDict.__setattr__': ('basics.html#attrdict.__setattr__', 'fastcore/basics.py'),
                                 'fastcore.basics.AttrDict._repr_markdown_': ('basics.html#attrdict._repr_markdown_', 'fastcore/basics.py'),
                                 'fastcore.basics.AttrDict.copy': ('basics.html#attrdict.copy', 'fastcore/basics.py'),
                                 'fastcore.basics.Float': ('basics.html#float', 'fastcore/basics.py'),
                                 'fastcore.basics.GetAttr': ('basics.html#getattr', 'fastcore/basics.py'),
                                 'fastcore.basics.GetAttr.__dir__': ('basics.html#getattr.__dir__', 'fastcore/basics.py'),
                                 'fastcore.basics.GetAttr.__getattr__': ('basics.html#getattr.__getattr__', 'fastcore/basics.py'),
                                 'fastcore.basics.GetAttr.__setstate__': ('basics.html#getattr.__setstate__', 'fastcore/basics.py'),
                                 'fastcore.basics.GetAttr._component_attr_filter': ( 'basics.html#getattr._component_attr_filter',
                                                                                     'fastcore/basics.py'),
                                 'fastcore.basics.GetAttr._dir': ('basics.html#getattr._dir', 'fastcore/basics.py'),
                                 'fastcore.basics.GetAttrBase': ('basics.html#getattrbase', 'fastcore/basics.py'),
                                 'fastcore.basics.GetAttrBase.__dir__': ('basics.html#getattrbase.__dir__', 'fastcore/basics.py'),
                                 'fastcore.basics.GetAttrBase.__getattr__': ('basics.html#getattrbase.__getattr__', 'fastcore/basics.py'),
                                 'fastcore.basics.ImportEnum': ('basics.html#importenum', 'fastcore/basics.py'),
                                 'fastcore.basics.ImportEnum.imports': ('basics.html#importenum.imports', 'fastcore/basics.py'),
                                 'fastcore.basics.Inf': ('basics.html#inf', 'fastcore/basics.py'),
                                 'fastcore.basics.Int': ('basics.html#int', 'fastcore/basics.py'),
                                 'fastcore.basics.NullType': ('basics.html#nulltype', 'fastcore/basics.py'),
                                 'fastcore.basics.NullType.__bool__': ('basics.html#nulltype.__bool__', 'fastcore/basics.py'),
                                 'fastcore.basics.NullType.__call__': ('basics.html#nulltype.__call__', 'fastcore/basics.py'),
                                 'fastcore.basics.NullType.__getattr__': ('basics.html#nulltype.__getattr__', 'fastcore/basics.py'),
                                 'fastcore.basics.NullType.__getitem__': ('basics.html#nulltype.__getitem__', 'fastcore/basics.py'),
                                 'fastcore.basics.PrettyString': ('basics.html#prettystring', 'fastcore/basics.py'),
                                 'fastcore.basics.PrettyString.__repr__': ('basics.html#prettystring.__repr__', 'fastcore/basics.py'),
                                 'fastcore.basics.ShowPrint': ('basics.html#showprint', 'fastcore/basics.py'),
                                 'fastcore.basics.ShowPrint.show': ('basics.html#showprint.show', 'fastcore/basics.py'),
                                 'fastcore.basics.Stateful': ('basics.html#stateful', 'fastcore/basics.py'),
                                 'fastcore.basics.Stateful.__getstate__': ('basics.html#stateful.__getstate__', 'fastcore/basics.py'),
                                 'fastcore.basics.Stateful.__init__': ('basics.html#stateful.__init__', 'fastcore/basics.py'),
                                 'fastcore.basics.Stateful.__setstate__': ('basics.html#stateful.__setstate__', 'fastcore/basics.py'),
                                 'fastcore.basics.Stateful._init_state': ('basics.html#stateful._init_state', 'fastcore/basics.py'),
                                 'fastcore.basics.Str': ('basics.html#str', 'fastcore/basics.py'),
                                 'fastcore.basics.StrEnum': ('basics.html#strenum', 'fastcore/basics.py'),
                                 'fastcore.basics.StrEnum.__str__': ('basics.html#strenum.__str__', 'fastcore/basics.py'),
                                 'fastcore.basics._Arg': ('basics.html#_arg', 'fastcore/basics.py'),
                                 'fastcore.basics._Arg.__init__': ('basics.html#_arg.__init__', 'fastcore/basics.py'),
                                 'fastcore.basics._InfMeta': ('basics.html#_infmeta', 'fastcore/basics.py'),
                                 'fastcore.basics._InfMeta.count': ('basics.html#_infmeta.count', 'fastcore/basics.py'),
                                 'fastcore.basics._InfMeta.nones': ('basics.html#_infmeta.nones', 'fastcore/basics.py'),
                                 'fastcore.basics._InfMeta.ones': ('basics.html#_infmeta.ones', 'fastcore/basics.py'),
                                 'fastcore.basics._InfMeta.zeros': ('basics.html#_infmeta.zeros', 'fastcore/basics.py'),
                                 'fastcore.basics._Self': ('basics.html#_self', 'fastcore/basics.py'),
                                 'fastcore.basics._Self.__call__': ('basics.html#_self.__call__', 'fastcore/basics.py'),
                                 'fastcore.basics._Self.__getattr__': ('basics.html#_self.__getattr__', 'fastcore/basics.py'),
                                 'fastcore.basics._Self.__init__': ('basics.html#_self.__init__', 'fastcore/basics.py'),
                                 'fastcore.basics._Self.__repr__': ('basics.html#_self.__repr__', 'fastcore/basics.py'),
                                 'fastcore.basics._Self._call': ('basics.html#_self._call', 'fastcore/basics.py'),
                                 'fastcore.basics._SelfCls': ('basics.html#_selfcls', 'fastcore/basics.py'),
                                 'fastcore.basics._SelfCls.__call__': ('basics.html#_selfcls.__call__', 'fastcore/basics.py'),
                                 'fastcore.basics._SelfCls.__getattr__': ('basics.html#_selfcls.__getattr__', 'fastcore/basics.py'),
                                 'fastcore.basics._SelfCls.__getitem__': ('basics.html#_selfcls.__getitem__', 'fastcore/basics.py'),
                                 'fastcore.basics._access': ('basics.html#_access', 'fastcore/basics.py'),
                                 'fastcore.basics._eval_type': ('basics.html#_eval_type', 'fastcore/basics.py'),
                                 'fastcore.basics._get_op': ('basics.html#_get_op', 'fastcore/basics.py'),
                                 'fastcore.basics._ispy3_10': ('basics.html#_ispy3_10', 'fastcore/basics.py'),
                                 'fastcore.basics._mk_op': ('basics.html#_mk_op', 'fastcore/basics.py'),
                                 'fastcore.basics._nested_idx': ('basics.html#_nested_idx', 'fastcore/basics.py'),
                                 'fastcore.basics._oper': ('basics.html#_oper', 'fastcore/basics.py'),
                                 'fastcore.basics._store_attr': ('basics.html#_store_attr', 'fastcore/basics.py'),
                                 'fastcore.basics._typeerr': ('basics.html#_typeerr', 'fastcore/basics.py'),
                                 'fastcore.basics._using_attr': ('basics.html#_using_attr', 'fastcore/basics.py'),
                                 'fastcore.basics.add_props': ('basics.html#add_props', 'fastcore/basics.py'),
                                 'fastcore.basics.anno_ret': ('basics.html#anno_ret', 'fastcore/basics.py'),
                                 'fastcore.basics.annotations': ('basics.html#annotations', 'fastcore/basics.py'),
                                 'fastcore.basics.argnames': ('basics.html#argnames', 'fastcore/basics.py'),
                                 'fastcore.basics.argwhere': ('basics.html#argwhere', 'fastcore/basics.py'),
                                 'fastcore.basics.attrdict': ('basics.html#attrdict', 'fastcore/basics.py'),
                                 'fastcore.basics.basic_repr': ('basics.html#basic_repr', 'fastcore/basics.py'),
                                 'fastcore.basics.bind': ('basics.html#bind', 'fastcore/basics.py'),
                                 'fastcore.basics.bind.__call__': ('basics.html#bind.__call__', 'fastcore/basics.py'),
                                 'fastcore.basics.bind.__init__': ('basics.html#bind.__init__', 'fastcore/basics.py'),
                                 'fastcore.basics.camel2snake': ('basics.html#camel2snake', 'fastcore/basics.py'),
                                 'fastcore.basics.camel2words': ('basics.html#camel2words', 'fastcore/basics.py'),
                                 'fastcore.basics.chunked': ('basics.html#chunked', 'fastcore/basics.py'),
                                 'fastcore.basics.class2attr': ('basics.html#class2attr', 'fastcore/basics.py'),
                                 'fastcore.basics.compile_re': ('basics.html#compile_re', 'fastcore/basics.py'),
                                 'fastcore.basics.compose': ('basics.html#compose', 'fastcore/basics.py'),
                                 'fastcore.basics.concat': ('basics.html#concat', 'fastcore/basics.py'),
                                 'fastcore.basics.copy_func': ('basics.html#copy_func', 'fastcore/basics.py'),
                                 'fastcore.basics.custom_dir': ('basics.html#custom_dir', 'fastcore/basics.py'),
                                 'fastcore.basics.cycle': ('basics.html#cycle', 'fastcore/basics.py'),
                                 'fastcore.basics.delegate_attr': ('basics.html#delegate_attr', 'fastcore/basics.py'),
                                 'fastcore.basics.detuplify': ('basics.html#detuplify', 'fastcore/basics.py'),
                                 'fastcore.basics.eval_type': ('basics.html#eval_type', 'fastcore/basics.py'),
                                 'fastcore.basics.even_mults': ('basics.html#even_mults', 'fastcore/basics.py'),
                                 'fastcore.basics.exec_import': ('basics.html#exec_import', 'fastcore/basics.py'),
                                 'fastcore.basics.exec_local': ('basics.html#exec_local', 'fastcore/basics.py'),
                                 'fastcore.basics.exec_new': ('basics.html#exec_new', 'fastcore/basics.py'),
                                 'fastcore.basics.fastuple': ('basics.html#fastuple', 'fastcore/basics.py'),
                                 'fastcore.basics.fastuple.__new__': ('basics.html#fastuple.__new__', 'fastcore/basics.py'),
                                 'fastcore.basics.fastuple._op': ('basics.html#fastuple._op', 'fastcore/basics.py'),
                                 'fastcore.basics.fastuple.add': ('basics.html#fastuple.add', 'fastcore/basics.py'),
                                 'fastcore.basics.fastuple.mul': ('basics.html#fastuple.mul', 'fastcore/basics.py'),
                                 'fastcore.basics.filter_dict': ('basics.html#filter_dict', 'fastcore/basics.py'),
                                 'fastcore.basics.filter_ex': ('basics.html#filter_ex', 'fastcore/basics.py'),
                                 'fastcore.basics.filter_keys': ('basics.html#filter_keys', 'fastcore/basics.py'),
                                 'fastcore.basics.filter_values': ('basics.html#filter_values', 'fastcore/basics.py'),
                                 'fastcore.basics.first': ('basics.html#first', 'fastcore/basics.py'),
                                 'fastcore.basics.flatten': ('basics.html#flatten', 'fastcore/basics.py'),
                                 'fastcore.basics.gen': ('basics.html#gen', 'fastcore/basics.py'),
                                 'fastcore.basics.get_annotations_ex': ('basics.html#get_annotations_ex', 'fastcore/basics.py'),
                                 'fastcore.basics.get_class': ('basics.html#get_class', 'fastcore/basics.py'),
                                 'fastcore.basics.getattrs': ('basics.html#getattrs', 'fastcore/basics.py'),
                                 'fastcore.basics.getcallable': ('basics.html#getcallable', 'fastcore/basics.py'),
                                 'fastcore.basics.groupby': ('basics.html#groupby', 'fastcore/basics.py'),
                                 'fastcore.basics.hasattrs': ('basics.html#hasattrs', 'fastcore/basics.py'),
                                 'fastcore.basics.ifnone': ('basics.html#ifnone', 'fastcore/basics.py'),
                                 'fastcore.basics.ignore_exceptions': ('basics.html#ignore_exceptions', 'fastcore/basics.py'),
                                 'fastcore.basics.ignore_exceptions.__enter__': ( 'basics.html#ignore_exceptions.__enter__',
                                                                                  'fastcore/basics.py'),
                                 'fastcore.basics.ignore_exceptions.__exit__': ( 'basics.html#ignore_exceptions.__exit__',
                                                                                 'fastcore/basics.py'),
                                 'fastcore.basics.in_': ('basics.html#in_', 'fastcore/basics.py'),
                                 'fastcore.basics.instantiate': ('basics.html#instantiate', 'fastcore/basics.py'),
                                 'fastcore.basics.is_array': ('basics.html#is_array', 'fastcore/basics.py'),
                                 'fastcore.basics.last_index': ('basics.html#last_index', 'fastcore/basics.py'),
                                 'fastcore.basics.listify': ('basics.html#listify', 'fastcore/basics.py'),
                                 'fastcore.basics.loop_first': ('basics.html#loop_first', 'fastcore/basics.py'),
                                 'fastcore.basics.loop_first_last': ('basics.html#loop_first_last', 'fastcore/basics.py'),
                                 'fastcore.basics.loop_last': ('basics.html#loop_last', 'fastcore/basics.py'),
                                 'fastcore.basics.map_ex': ('basics.html#map_ex', 'fastcore/basics.py'),
                                 'fastcore.basics.maps': ('basics.html#maps', 'fastcore/basics.py'),
                                 'fastcore.basics.mapt': ('basics.html#mapt', 'fastcore/basics.py'),
                                 'fastcore.basics.maybe_attr': ('basics.html#maybe_attr', 'fastcore/basics.py'),
                                 'fastcore.basics.merge': ('basics.html#merge', 'fastcore/basics.py'),
                                 'fastcore.basics.mk_class': ('basics.html#mk_class', 'fastcore/basics.py'),
                                 'fastcore.basics.nested_attr': ('basics.html#nested_attr', 'fastcore/basics.py'),
                                 'fastcore.basics.nested_callable': ('basics.html#nested_callable', 'fastcore/basics.py'),
                                 'fastcore.basics.nested_idx': ('basics.html#nested_idx', 'fastcore/basics.py'),
                                 'fastcore.basics.nested_setdefault': ('basics.html#nested_setdefault', 'fastcore/basics.py'),
                                 'fastcore.basics.not_': ('basics.html#not_', 'fastcore/basics.py'),
                                 'fastcore.basics.num_cpus': ('basics.html#num_cpus', 'fastcore/basics.py'),
                                 'fastcore.basics.only': ('basics.html#only', 'fastcore/basics.py'),
                                 'fastcore.basics.otherwise': ('basics.html#otherwise', 'fastcore/basics.py'),
                                 'fastcore.basics.partialler': ('basics.html#partialler', 'fastcore/basics.py'),
                                 'fastcore.basics.patch': ('basics.html#patch', 'fastcore/basics.py'),
                                 'fastcore.basics.patch_property': ('basics.html#patch_property', 'fastcore/basics.py'),
                                 'fastcore.basics.patch_to': ('basics.html#patch_to', 'fastcore/basics.py'),
                                 'fastcore.basics.properties': ('basics.html#properties', 'fastcore/basics.py'),
                                 'fastcore.basics.range_of': ('basics.html#range_of', 'fastcore/basics.py'),
                                 'fastcore.basics.renumerate': ('basics.html#renumerate', 'fastcore/basics.py'),
                                 'fastcore.basics.replicate': ('basics.html#replicate', 'fastcore/basics.py'),
                                 'fastcore.basics.ret_false': ('basics.html#ret_false', 'fastcore/basics.py'),
                                 'fastcore.basics.ret_true': ('basics.html#ret_true', 'fastcore/basics.py'),
                                 'fastcore.basics.risinstance': ('basics.html#risinstance', 'fastcore/basics.py'),
                                 'fastcore.basics.set_nested_idx': ('basics.html#set_nested_idx', 'fastcore/basics.py'),
                                 'fastcore.basics.setattrs': ('basics.html#setattrs', 'fastcore/basics.py'),
                                 'fastcore.basics.setify': ('basics.html#setify', 'fastcore/basics.py'),
                                 'fastcore.basics.signature_ex': ('basics.html#signature_ex', 'fastcore/basics.py'),
                                 'fastcore.basics.snake2camel': ('basics.html#snake2camel', 'fastcore/basics.py'),
                                 'fastcore.basics.sorted_ex': ('basics.html#sorted_ex', 'fastcore/basics.py'),
                                 'fastcore.basics.stop': ('basics.html#stop', 'fastcore/basics.py'),
                                 'fastcore.basics.store_attr': ('basics.html#store_attr', 'fastcore/basics.py'),
                                 'fastcore.basics.str2bool': ('basics.html#str2bool', 'fastcore/basics.py'),
                                 'fastcore.basics.str_enum': ('basics.html#str_enum', 'fastcore/basics.py'),
                                 'fastcore.basics.strcat': ('basics.html#strcat', 'fastcore/basics.py'),
                                 'fastcore.basics.tonull': ('basics.html#tonull', 'fastcore/basics.py'),
                                 'fastcore.basics.true': ('basics.html#true', 'fastcore/basics.py'),
                                 'fastcore.basics.try_attrs': ('basics.html#try_attrs', 'fastcore/basics.py'),
                                 'fastcore.basics.tuplify': ('basics.html#tuplify', 'fastcore/basics.py'),
                                 'fastcore.basics.type_hints': ('basics.html#type_hints', 'fastcore/basics.py'),
                                 'fastcore.basics.typed': ('basics.html#typed', 'fastcore/basics.py'),
                                 'fastcore.basics.union2tuple': ('basics.html#union2tuple', 'fastcore/basics.py'),
                                 'fastcore.basics.uniqueify': ('basics.html#uniqueify', 'fastcore/basics.py'),
                                 'fastcore.basics.using_attr': ('basics.html#using_attr', 'fastcore/basics.py'),
                                 'fastcore.basics.val2idx': ('basics.html#val2idx', 'fastcore/basics.py'),
                                 'fastcore.basics.with_cast': ('basics.html#with_cast', 'fastcore/basics.py'),
                                 'fastcore.basics.wrap_class': ('basics.html#wrap_class', 'fastcore/basics.py'),
                                 'fastcore.basics.zip_cycle': ('basics.html#zip_cycle', 'fastcore/basics.py')},
            'fastcore.dispatch': { 'fastcore.dispatch.DispatchReg': ('dispatch.html#dispatchreg', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.DispatchReg.__call__': ('dispatch.html#dispatchreg.__call__', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.DispatchReg.__init__': ('dispatch.html#dispatchreg.__init__', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch': ('dispatch.html#typedispatch', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch.__call__': ( 'dispatch.html#typedispatch.__call__',
                                                                                'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch.__get__': ('dispatch.html#typedispatch.__get__', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch.__getitem__': ( 'dispatch.html#typedispatch.__getitem__',
                                                                                   'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch.__init__': ( 'dispatch.html#typedispatch.__init__',
                                                                                'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch.__repr__': ( 'dispatch.html#typedispatch.__repr__',
                                                                                'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch._attname': ( 'dispatch.html#typedispatch._attname',
                                                                                'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch.add': ('dispatch.html#typedispatch.add', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch.first': ('dispatch.html#typedispatch.first', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.TypeDispatch.returns': ('dispatch.html#typedispatch.returns', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch._TypeDict': ('dispatch.html#_typedict', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch._TypeDict.__getitem__': ( 'dispatch.html#_typedict.__getitem__',
                                                                                'fastcore/dispatch.py'),
                                   'fastcore.dispatch._TypeDict.__init__': ('dispatch.html#_typedict.__init__', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch._TypeDict.__repr__': ('dispatch.html#_typedict.__repr__', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch._TypeDict._reset': ('dispatch.html#_typedict._reset', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch._TypeDict.add': ('dispatch.html#_typedict.add', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch._TypeDict.all_matches': ( 'dispatch.html#_typedict.all_matches',
                                                                                'fastcore/dispatch.py'),
                                   'fastcore.dispatch._TypeDict.first': ('dispatch.html#_typedict.first', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch._chk_defaults': ('dispatch.html#_chk_defaults', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch._p2_anno': ('dispatch.html#_p2_anno', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.cast': ('dispatch.html#cast', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.default_set_meta': ('dispatch.html#default_set_meta', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.explode_types': ('dispatch.html#explode_types', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.lenient_issubclass': ('dispatch.html#lenient_issubclass', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.retain_meta': ('dispatch.html#retain_meta', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.retain_type': ('dispatch.html#retain_type', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.retain_types': ('dispatch.html#retain_types', 'fastcore/dispatch.py'),
                                   'fastcore.dispatch.sorted_topologically': ( 'dispatch.html#sorted_topologically',
                                                                               'fastcore/dispatch.py')},
            'fastcore.docments': { 'fastcore.docments._clean_comment': ('docments.html#_clean_comment', 'fastcore/docments.py'),
                                   'fastcore.docments._docments': ('docments.html#_docments', 'fastcore/docments.py'),
                                   'fastcore.docments._get_comment': ('docments.html#_get_comment', 'fastcore/docments.py'),
                                   'fastcore.docments._get_full': ('docments.html#_get_full', 'fastcore/docments.py'),
                                   'fastcore.docments._get_property_name': ('docments.html#_get_property_name', 'fastcore/docments.py'),
                                   'fastcore.docments._merge_doc': ('docments.html#_merge_doc', 'fastcore/docments.py'),
                                   'fastcore.docments._merge_docs': ('docments.html#_merge_docs', 'fastcore/docments.py'),
                                   'fastcore.docments._param_locs': ('docments.html#_param_locs', 'fastcore/docments.py'),
                                   'fastcore.docments._parses': ('docments.html#_parses', 'fastcore/docments.py'),
                                   'fastcore.docments._tokens': ('docments.html#_tokens', 'fastcore/docments.py'),
                                   'fastcore.docments.docments': ('docments.html#docments', 'fastcore/docments.py'),
                                   'fastcore.docments.docstring': ('docments.html#docstring', 'fastcore/docments.py'),
                                   'fastcore.docments.get_dataclass_source': ('docments.html#get_dataclass_source', 'fastcore/docments.py'),
                                   'fastcore.docments.get_name': ('docments.html#get_name', 'fastcore/docments.py'),
                                   'fastcore.docments.get_source': ('docments.html#get_source', 'fastcore/docments.py'),
                                   'fastcore.docments.isdataclass': ('docments.html#isdataclass', 'fastcore/docments.py'),
                                   'fastcore.docments.parse_docstring': ('docments.html#parse_docstring', 'fastcore/docments.py'),
                                   'fastcore.docments.qual_name': ('docments.html#qual_name', 'fastcore/docments.py')},
            'fastcore.docscrape': {},
            'fastcore.foundation': { 'fastcore.foundation.CollBase': ('foundation.html#collbase', 'fastcore/foundation.py'),
                                     'fastcore.foundation.CollBase.__delitem__': ( 'foundation.html#collbase.__delitem__',
                                                                                   'fastcore/foundation.py'),
                                     'fastcore.foundation.CollBase.__getitem__': ( 'foundation.html#collbase.__getitem__',
                                                                                   'fastcore/foundation.py'),
                                     'fastcore.foundation.CollBase.__init__': ( 'foundation.html#collbase.__init__',
                                                                                'fastcore/foundation.py'),
                                     'fastcore.foundation.CollBase.__iter__': ( 'foundation.html#collbase.__iter__',
                                                                                'fastcore/foundation.py'),
                                     'fastcore.foundation.CollBase.__len__': ('foundation.html#collbase.__len__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.CollBase.__repr__': ( 'foundation.html#collbase.__repr__',
                                                                                'fastcore/foundation.py'),
                                     'fastcore.foundation.CollBase.__setitem__': ( 'foundation.html#collbase.__setitem__',
                                                                                   'fastcore/foundation.py'),
                                     'fastcore.foundation.Config': ('foundation.html#config', 'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.__contains__': ( 'foundation.html#config.__contains__',
                                                                                  'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.__getattr__': ( 'foundation.html#config.__getattr__',
                                                                                 'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.__getitem__': ( 'foundation.html#config.__getitem__',
                                                                                 'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.__init__': ('foundation.html#config.__init__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.__repr__': ('foundation.html#config.__repr__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.__setitem__': ( 'foundation.html#config.__setitem__',
                                                                                 'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.get': ('foundation.html#config.get', 'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.path': ('foundation.html#config.path', 'fastcore/foundation.py'),
                                     'fastcore.foundation.Config.save': ('foundation.html#config.save', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L': ('foundation.html#l', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__add__': ('foundation.html#l.__add__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__addi__': ('foundation.html#l.__addi__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__contains__': ('foundation.html#l.__contains__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__eq__': ('foundation.html#l.__eq__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__getitem__': ('foundation.html#l.__getitem__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__init__': ('foundation.html#l.__init__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__invert__': ('foundation.html#l.__invert__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__iter__': ('foundation.html#l.__iter__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__mul__': ('foundation.html#l.__mul__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__radd__': ('foundation.html#l.__radd__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__repr__': ('foundation.html#l.__repr__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__reversed__': ('foundation.html#l.__reversed__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.__setitem__': ('foundation.html#l.__setitem__', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L._get': ('foundation.html#l._get', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L._new': ('foundation.html#l._new', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L._repr_pretty_': ('foundation.html#l._repr_pretty_', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L._xtra': ('foundation.html#l._xtra', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.argfirst': ('foundation.html#l.argfirst', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.argwhere': ('foundation.html#l.argwhere', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.attrgot': ('foundation.html#l.attrgot', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.concat': ('foundation.html#l.concat', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.copy': ('foundation.html#l.copy', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.cycle': ('foundation.html#l.cycle', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.enumerate': ('foundation.html#l.enumerate', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.filter': ('foundation.html#l.filter', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.itemgot': ('foundation.html#l.itemgot', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.map': ('foundation.html#l.map', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.map_dict': ('foundation.html#l.map_dict', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.map_first': ('foundation.html#l.map_first', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.map_zip': ('foundation.html#l.map_zip', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.map_zipwith': ('foundation.html#l.map_zipwith', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.product': ('foundation.html#l.product', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.range': ('foundation.html#l.range', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.reduce': ('foundation.html#l.reduce', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.renumerate': ('foundation.html#l.renumerate', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.setattrs': ('foundation.html#l.setattrs', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.shuffle': ('foundation.html#l.shuffle', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.sorted': ('foundation.html#l.sorted', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.split': ('foundation.html#l.split', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.starmap': ('foundation.html#l.starmap', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.sum': ('foundation.html#l.sum', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.unique': ('foundation.html#l.unique', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.val2idx': ('foundation.html#l.val2idx', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.zip': ('foundation.html#l.zip', 'fastcore/foundation.py'),
                                     'fastcore.foundation.L.zipwith': ('foundation.html#l.zipwith', 'fastcore/foundation.py'),
                                     'fastcore.foundation._L_Meta': ('foundation.html#_l_meta', 'fastcore/foundation.py'),
                                     'fastcore.foundation._L_Meta.__call__': ('foundation.html#_l_meta.__call__', 'fastcore/foundation.py'),
                                     'fastcore.foundation._f': ('foundation.html#_f', 'fastcore/foundation.py'),
                                     'fastcore.foundation.add_docs': ('foundation.html#add_docs', 'fastcore/foundation.py'),
                                     'fastcore.foundation.coll_repr': ('foundation.html#coll_repr', 'fastcore/foundation.py'),
                                     'fastcore.foundation.cycle': ('foundation.html#cycle', 'fastcore/foundation.py'),
                                     'fastcore.foundation.docs': ('foundation.html#docs', 'fastcore/foundation.py'),
                                     'fastcore.foundation.is_bool': ('foundation.html#is_bool', 'fastcore/foundation.py'),
                                     'fastcore.foundation.is_indexer': ('foundation.html#is_indexer', 'fastcore/foundation.py'),
                                     'fastcore.foundation.mask2idxs': ('foundation.html#mask2idxs', 'fastcore/foundation.py'),
                                     'fastcore.foundation.read_config_file': ('foundation.html#read_config_file', 'fastcore/foundation.py'),
                                     'fastcore.foundation.save_config_file': ('foundation.html#save_config_file', 'fastcore/foundation.py'),
                                     'fastcore.foundation.working_directory': ( 'foundation.html#working_directory',
                                                                                'fastcore/foundation.py'),
                                     'fastcore.foundation.zip_cycle': ('foundation.html#zip_cycle', 'fastcore/foundation.py')},
            'fastcore.imports': {},
            'fastcore.meta': { 'fastcore.meta.AutoInit': ('meta.html#autoinit', 'fastcore/meta.py'),
                               'fastcore.meta.AutoInit.__pre_init__': ('meta.html#autoinit.__pre_init__', 'fastcore/meta.py'),
                               'fastcore.meta.BypassNewMeta': ('meta.html#bypassnewmeta', 'fastcore/meta.py'),
                               'fastcore.meta.BypassNewMeta.__call__': ('meta.html#bypassnewmeta.__call__', 'fastcore/meta.py'),
                               'fastcore.meta.FixSigMeta': ('meta.html#fixsigmeta', 'fastcore/meta.py'),
                               'fastcore.meta.FixSigMeta.__new__': ('meta.html#fixsigmeta.__new__', 'fastcore/meta.py'),
                               'fastcore.meta.NewChkMeta': ('meta.html#newchkmeta', 'fastcore/meta.py'),
                               'fastcore.meta.NewChkMeta.__call__': ('meta.html#newchkmeta.__call__', 'fastcore/meta.py'),
                               'fastcore.meta.PrePostInitMeta': ('meta.html#prepostinitmeta', 'fastcore/meta.py'),
                               'fastcore.meta.PrePostInitMeta.__call__': ('meta.html#prepostinitmeta.__call__', 'fastcore/meta.py'),
                               'fastcore.meta._funcs_kwargs': ('meta.html#_funcs_kwargs', 'fastcore/meta.py'),
                               'fastcore.meta._mk_param': ('meta.html#_mk_param', 'fastcore/meta.py'),
                               'fastcore.meta._rm_self': ('meta.html#_rm_self', 'fastcore/meta.py'),
                               'fastcore.meta.anno_dict': ('meta.html#anno_dict', 'fastcore/meta.py'),
                               'fastcore.meta.delegates': ('meta.html#delegates', 'fastcore/meta.py'),
                               'fastcore.meta.empty2none': ('meta.html#empty2none', 'fastcore/meta.py'),
                               'fastcore.meta.funcs_kwargs': ('meta.html#funcs_kwargs', 'fastcore/meta.py'),
                               'fastcore.meta.method': ('meta.html#method', 'fastcore/meta.py'),
                               'fastcore.meta.test_sig': ('meta.html#test_sig', 'fastcore/meta.py'),
                               'fastcore.meta.use_kwargs': ('meta.html#use_kwargs', 'fastcore/meta.py'),
                               'fastcore.meta.use_kwargs_dict': ('meta.html#use_kwargs_dict', 'fastcore/meta.py')},
            'fastcore.nb_imports': {},
            'fastcore.net': { 'fastcore.net.HTTP4xxClientError': ('net.html#http4xxclienterror', 'fastcore/net.py'),
                              'fastcore.net.HTTP5xxServerError': ('net.html#http5xxservererror', 'fastcore/net.py'),
                              'fastcore.net.Request.summary': ('net.html#request.summary', 'fastcore/net.py'),
                              'fastcore.net._socket_det': ('net.html#_socket_det', 'fastcore/net.py'),
                              'fastcore.net.do_request': ('net.html#do_request', 'fastcore/net.py'),
                              'fastcore.net.start_client': ('net.html#start_client', 'fastcore/net.py'),
                              'fastcore.net.start_server': ('net.html#start_server', 'fastcore/net.py'),
                              'fastcore.net.urlcheck': ('net.html#urlcheck', 'fastcore/net.py'),
                              'fastcore.net.urlclean': ('net.html#urlclean', 'fastcore/net.py'),
                              'fastcore.net.urldest': ('net.html#urldest', 'fastcore/net.py'),
                              'fastcore.net.urljson': ('net.html#urljson', 'fastcore/net.py'),
                              'fastcore.net.urlopen': ('net.html#urlopen', 'fastcore/net.py'),
                              'fastcore.net.urlopener': ('net.html#urlopener', 'fastcore/net.py'),
                              'fastcore.net.urlquote': ('net.html#urlquote', 'fastcore/net.py'),
                              'fastcore.net.urlread': ('net.html#urlread', 'fastcore/net.py'),
                              'fastcore.net.urlrequest': ('net.html#urlrequest', 'fastcore/net.py'),
                              'fastcore.net.urlretrieve': ('net.html#urlretrieve', 'fastcore/net.py'),
                              'fastcore.net.urlsave': ('net.html#urlsave', 'fastcore/net.py'),
                              'fastcore.net.urlsend': ('net.html#urlsend', 'fastcore/net.py'),
                              'fastcore.net.urlvalid': ('net.html#urlvalid', 'fastcore/net.py'),
                              'fastcore.net.urlwrap': ('net.html#urlwrap', 'fastcore/net.py')},
            'fastcore.parallel': { 'fastcore.parallel.ProcessPoolExecutor': ('parallel.html#processpoolexecutor', 'fastcore/parallel.py'),
                                   'fastcore.parallel.ProcessPoolExecutor.__init__': ( 'parallel.html#processpoolexecutor.__init__',
                                                                                       'fastcore/parallel.py'),
                                   'fastcore.parallel.ProcessPoolExecutor.map': ( 'parallel.html#processpoolexecutor.map',
                                                                                  'fastcore/parallel.py'),
                                   'fastcore.parallel.ThreadPoolExecutor': ('parallel.html#threadpoolexecutor', 'fastcore/parallel.py'),
                                   'fastcore.parallel.ThreadPoolExecutor.__init__': ( 'parallel.html#threadpoolexecutor.__init__',
                                                                                      'fastcore/parallel.py'),
                                   'fastcore.parallel.ThreadPoolExecutor.map': ( 'parallel.html#threadpoolexecutor.map',
                                                                                 'fastcore/parallel.py'),
                                   'fastcore.parallel._call': ('parallel.html#_call', 'fastcore/parallel.py'),
                                   'fastcore.parallel._done_pg': ('parallel.html#_done_pg', 'fastcore/parallel.py'),
                                   'fastcore.parallel._f_pg': ('parallel.html#_f_pg', 'fastcore/parallel.py'),
                                   'fastcore.parallel.add_one': ('parallel.html#add_one', 'fastcore/parallel.py'),
                                   'fastcore.parallel.parallel': ('parallel.html#parallel', 'fastcore/parallel.py'),
                                   'fastcore.parallel.parallel_gen': ('parallel.html#parallel_gen', 'fastcore/parallel.py'),
                                   'fastcore.parallel.parallelable': ('parallel.html#parallelable', 'fastcore/parallel.py'),
                                   'fastcore.parallel.run_procs': ('parallel.html#run_procs', 'fastcore/parallel.py'),
                                   'fastcore.parallel.startthread': ('parallel.html#startthread', 'fastcore/parallel.py'),
                                   'fastcore.parallel.threaded': ('parallel.html#threaded', 'fastcore/parallel.py')},
            'fastcore.script': { 'fastcore.script.Param': ('script.html#param', 'fastcore/script.py'),
                                 'fastcore.script.Param.__init__': ('script.html#param.__init__', 'fastcore/script.py'),
                                 'fastcore.script.Param.__repr__': ('script.html#param.__repr__', 'fastcore/script.py'),
                                 'fastcore.script.Param.kwargs': ('script.html#param.kwargs', 'fastcore/script.py'),
                                 'fastcore.script.Param.pre': ('script.html#param.pre', 'fastcore/script.py'),
                                 'fastcore.script.Param.set_default': ('script.html#param.set_default', 'fastcore/script.py'),
                                 'fastcore.script._HelpFormatter': ('script.html#_helpformatter', 'fastcore/script.py'),
                                 'fastcore.script._HelpFormatter.__init__': ('script.html#_helpformatter.__init__', 'fastcore/script.py'),
                                 'fastcore.script._HelpFormatter._expand_help': ( 'script.html#_helpformatter._expand_help',
                                                                                  'fastcore/script.py'),
                                 'fastcore.script.anno_parser': ('script.html#anno_parser', 'fastcore/script.py'),
                                 'fastcore.script.args_from_prog': ('script.html#args_from_prog', 'fastcore/script.py'),
                                 'fastcore.script.bool_arg': ('script.html#bool_arg', 'fastcore/script.py'),
                                 'fastcore.script.call_parse': ('script.html#call_parse', 'fastcore/script.py'),
                                 'fastcore.script.clean_type_str': ('script.html#clean_type_str', 'fastcore/script.py'),
                                 'fastcore.script.store_false': ('script.html#store_false', 'fastcore/script.py'),
                                 'fastcore.script.store_true': ('script.html#store_true', 'fastcore/script.py')},
            'fastcore.shutil': {},
            'fastcore.style': { 'fastcore.style.Style': ('style.html#style', 'fastcore/style.py'),
                                'fastcore.style.Style.__call__': ('style.html#style.__call__', 'fastcore/style.py'),
                                'fastcore.style.Style.__dir__': ('style.html#style.__dir__', 'fastcore/style.py'),
                                'fastcore.style.Style.__getattr__': ('style.html#style.__getattr__', 'fastcore/style.py'),
                                'fastcore.style.Style.__init__': ('style.html#style.__init__', 'fastcore/style.py'),
                                'fastcore.style.Style.__repr__': ('style.html#style.__repr__', 'fastcore/style.py'),
                                'fastcore.style.StyleCode': ('style.html#stylecode', 'fastcore/style.py'),
                                'fastcore.style.StyleCode.__init__': ('style.html#stylecode.__init__', 'fastcore/style.py'),
                                'fastcore.style.StyleCode.__str__': ('style.html#stylecode.__str__', 'fastcore/style.py'),
                                'fastcore.style._demo': ('style.html#_demo', 'fastcore/style.py'),
                                'fastcore.style._mk_codes': ('style.html#_mk_codes', 'fastcore/style.py'),
                                'fastcore.style._reset_code': ('style.html#_reset_code', 'fastcore/style.py'),
                                'fastcore.style.demo': ('style.html#demo', 'fastcore/style.py')},
            'fastcore.test': { 'fastcore.test.ExceptionExpected': ('test.html#exceptionexpected', 'fastcore/test.py'),
                               'fastcore.test.ExceptionExpected.__enter__': ('test.html#exceptionexpected.__enter__', 'fastcore/test.py'),
                               'fastcore.test.ExceptionExpected.__exit__': ('test.html#exceptionexpected.__exit__', 'fastcore/test.py'),
                               'fastcore.test.ExceptionExpected.__init__': ('test.html#exceptionexpected.__init__', 'fastcore/test.py'),
                               'fastcore.test.is_close': ('test.html#is_close', 'fastcore/test.py'),
                               'fastcore.test.nequals': ('test.html#nequals', 'fastcore/test.py'),
                               'fastcore.test.test': ('test.html#test', 'fastcore/test.py'),
                               'fastcore.test.test_close': ('test.html#test_close', 'fastcore/test.py'),
                               'fastcore.test.test_eq': ('test.html#test_eq', 'fastcore/test.py'),
                               'fastcore.test.test_eq_type': ('test.html#test_eq_type', 'fastcore/test.py'),
                               'fastcore.test.test_fail': ('test.html#test_fail', 'fastcore/test.py'),
                               'fastcore.test.test_fig_exists': ('test.html#test_fig_exists', 'fastcore/test.py'),
                               'fastcore.test.test_is': ('test.html#test_is', 'fastcore/test.py'),
                               'fastcore.test.test_ne': ('test.html#test_ne', 'fastcore/test.py'),
                               'fastcore.test.test_shuffled': ('test.html#test_shuffled', 'fastcore/test.py'),
                               'fastcore.test.test_stdout': ('test.html#test_stdout', 'fastcore/test.py'),
                               'fastcore.test.test_warns': ('test.html#test_warns', 'fastcore/test.py')},
            'fastcore.transform': { 'fastcore.transform.DisplayedTransform': ('transform.html#displayedtransform', 'fastcore/transform.py'),
                                    'fastcore.transform.DisplayedTransform.name': ( 'transform.html#displayedtransform.name',
                                                                                    'fastcore/transform.py'),
                                    'fastcore.transform.Func': ('transform.html#func', 'fastcore/transform.py'),
                                    'fastcore.transform.Func.__call__': ('transform.html#func.__call__', 'fastcore/transform.py'),
                                    'fastcore.transform.Func.__init__': ('transform.html#func.__init__', 'fastcore/transform.py'),
                                    'fastcore.transform.Func.__repr__': ('transform.html#func.__repr__', 'fastcore/transform.py'),
                                    'fastcore.transform.Func._get': ('transform.html#func._get', 'fastcore/transform.py'),
                                    'fastcore.transform.InplaceTransform': ('transform.html#inplacetransform', 'fastcore/transform.py'),
                                    'fastcore.transform.InplaceTransform._call': ( 'transform.html#inplacetransform._call',
                                                                                   'fastcore/transform.py'),
                                    'fastcore.transform.ItemTransform': ('transform.html#itemtransform', 'fastcore/transform.py'),
                                    'fastcore.transform.ItemTransform.__call__': ( 'transform.html#itemtransform.__call__',
                                                                                   'fastcore/transform.py'),
                                    'fastcore.transform.ItemTransform._call1': ( 'transform.html#itemtransform._call1',
                                                                                 'fastcore/transform.py'),
                                    'fastcore.transform.ItemTransform.decode': ( 'transform.html#itemtransform.decode',
                                                                                 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline': ('transform.html#pipeline', 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.__call__': ('transform.html#pipeline.__call__', 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.__dir__': ('transform.html#pipeline.__dir__', 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.__getattr__': ( 'transform.html#pipeline.__getattr__',
                                                                                 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.__getitem__': ( 'transform.html#pipeline.__getitem__',
                                                                                 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.__init__': ('transform.html#pipeline.__init__', 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.__repr__': ('transform.html#pipeline.__repr__', 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.__setstate__': ( 'transform.html#pipeline.__setstate__',
                                                                                  'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline._is_showable': ( 'transform.html#pipeline._is_showable',
                                                                                  'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.add': ('transform.html#pipeline.add', 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.decode': ('transform.html#pipeline.decode', 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.setup': ('transform.html#pipeline.setup', 'fastcore/transform.py'),
                                    'fastcore.transform.Pipeline.show': ('transform.html#pipeline.show', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform': ('transform.html#transform', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform.__call__': ('transform.html#transform.__call__', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform.__init__': ('transform.html#transform.__init__', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform.__repr__': ('transform.html#transform.__repr__', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform._call': ('transform.html#transform._call', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform._do_call': ('transform.html#transform._do_call', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform.decode': ('transform.html#transform.decode', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform.name': ('transform.html#transform.name', 'fastcore/transform.py'),
                                    'fastcore.transform.Transform.setup': ('transform.html#transform.setup', 'fastcore/transform.py'),
                                    'fastcore.transform._Sig': ('transform.html#_sig', 'fastcore/transform.py'),
                                    'fastcore.transform._Sig.__getattr__': ('transform.html#_sig.__getattr__', 'fastcore/transform.py'),
                                    'fastcore.transform._TfmDict': ('transform.html#_tfmdict', 'fastcore/transform.py'),
                                    'fastcore.transform._TfmDict.__setitem__': ( 'transform.html#_tfmdict.__setitem__',
                                                                                 'fastcore/transform.py'),
                                    'fastcore.transform._TfmMeta': ('transform.html#_tfmmeta', 'fastcore/transform.py'),
                                    'fastcore.transform._TfmMeta.__call__': ('transform.html#_tfmmeta.__call__', 'fastcore/transform.py'),
                                    'fastcore.transform._TfmMeta.__new__': ('transform.html#_tfmmeta.__new__', 'fastcore/transform.py'),
                                    'fastcore.transform._TfmMeta.__prepare__': ( 'transform.html#_tfmmeta.__prepare__',
                                                                                 'fastcore/transform.py'),
                                    'fastcore.transform._get_name': ('transform.html#_get_name', 'fastcore/transform.py'),
                                    'fastcore.transform._is_tfm_method': ('transform.html#_is_tfm_method', 'fastcore/transform.py'),
                                    'fastcore.transform._is_tuple': ('transform.html#_is_tuple', 'fastcore/transform.py'),
                                    'fastcore.transform.compose_tfms': ('transform.html#compose_tfms', 'fastcore/transform.py'),
                                    'fastcore.transform.gather_attr_names': ('transform.html#gather_attr_names', 'fastcore/transform.py'),
                                    'fastcore.transform.gather_attrs': ('transform.html#gather_attrs', 'fastcore/transform.py'),
                                    'fastcore.transform.get_func': ('transform.html#get_func', 'fastcore/transform.py'),
                                    'fastcore.transform.mk_transform': ('transform.html#mk_transform', 'fastcore/transform.py')},
            'fastcore.utils': {},
            'fastcore.xdg': { 'fastcore.xdg._path_from_env': ('xdg.html#_path_from_env', 'fastcore/xdg.py'),
                              'fastcore.xdg._paths_from_env': ('xdg.html#_paths_from_env', 'fastcore/xdg.py'),
                              'fastcore.xdg.xdg_cache_home': ('xdg.html#xdg_cache_home', 'fastcore/xdg.py'),
                              'fastcore.xdg.xdg_config_dirs': ('xdg.html#xdg_config_dirs', 'fastcore/xdg.py'),
                              'fastcore.xdg.xdg_config_home': ('xdg.html#xdg_config_home', 'fastcore/xdg.py'),
                              'fastcore.xdg.xdg_data_dirs': ('xdg.html#xdg_data_dirs', 'fastcore/xdg.py'),
                              'fastcore.xdg.xdg_data_home': ('xdg.html#xdg_data_home', 'fastcore/xdg.py'),
                              'fastcore.xdg.xdg_runtime_dir': ('xdg.html#xdg_runtime_dir', 'fastcore/xdg.py'),
                              'fastcore.xdg.xdg_state_home': ('xdg.html#xdg_state_home', 'fastcore/xdg.py')},
            'fastcore.xtras': { 'fastcore.xtras.ContextManagers': ('xtras.html#contextmanagers', 'fastcore/xtras.py'),
                                'fastcore.xtras.ContextManagers.__enter__': ('xtras.html#contextmanagers.__enter__', 'fastcore/xtras.py'),
                                'fastcore.xtras.ContextManagers.__exit__': ('xtras.html#contextmanagers.__exit__', 'fastcore/xtras.py'),
                                'fastcore.xtras.ContextManagers.__init__': ('xtras.html#contextmanagers.__init__', 'fastcore/xtras.py'),
                                'fastcore.xtras.EventTimer': ('xtras.html#eventtimer', 'fastcore/xtras.py'),
                                'fastcore.xtras.EventTimer.__init__': ('xtras.html#eventtimer.__init__', 'fastcore/xtras.py'),
                                'fastcore.xtras.EventTimer._reset': ('xtras.html#eventtimer._reset', 'fastcore/xtras.py'),
                                'fastcore.xtras.EventTimer.add': ('xtras.html#eventtimer.add', 'fastcore/xtras.py'),
                                'fastcore.xtras.EventTimer.duration': ('xtras.html#eventtimer.duration', 'fastcore/xtras.py'),
                                'fastcore.xtras.EventTimer.freq': ('xtras.html#eventtimer.freq', 'fastcore/xtras.py'),
                                'fastcore.xtras.IterLen': ('xtras.html#iterlen', 'fastcore/xtras.py'),
                                'fastcore.xtras.IterLen.__iter__': ('xtras.html#iterlen.__iter__', 'fastcore/xtras.py'),
                                'fastcore.xtras.PartialFormatter': ('xtras.html#partialformatter', 'fastcore/xtras.py'),
                                'fastcore.xtras.PartialFormatter.__init__': ('xtras.html#partialformatter.__init__', 'fastcore/xtras.py'),
                                'fastcore.xtras.PartialFormatter.check_unused_args': ( 'xtras.html#partialformatter.check_unused_args',
                                                                                       'fastcore/xtras.py'),
                                'fastcore.xtras.PartialFormatter.get_field': ('xtras.html#partialformatter.get_field', 'fastcore/xtras.py'),
                                'fastcore.xtras.Path.__repr__': ('xtras.html#path.__repr__', 'fastcore/xtras.py'),
                                'fastcore.xtras.Path.delete': ('xtras.html#path.delete', 'fastcore/xtras.py'),
                                'fastcore.xtras.Path.ls': ('xtras.html#path.ls', 'fastcore/xtras.py'),
                                'fastcore.xtras.Path.mk_write': ('xtras.html#path.mk_write', 'fastcore/xtras.py'),
                                'fastcore.xtras.Path.read_json': ('xtras.html#path.read_json', 'fastcore/xtras.py'),
                                'fastcore.xtras.Path.readlines': ('xtras.html#path.readlines', 'fastcore/xtras.py'),
                                'fastcore.xtras.Path.relpath': ('xtras.html#path.relpath', 'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection': ('xtras.html#reindexcollection', 'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection.__getitem__': ( 'xtras.html#reindexcollection.__getitem__',
                                                                                  'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection.__getstate__': ( 'xtras.html#reindexcollection.__getstate__',
                                                                                   'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection.__init__': ('xtras.html#reindexcollection.__init__', 'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection.__len__': ('xtras.html#reindexcollection.__len__', 'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection.__setstate__': ( 'xtras.html#reindexcollection.__setstate__',
                                                                                   'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection._get': ('xtras.html#reindexcollection._get', 'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection.cache_clear': ( 'xtras.html#reindexcollection.cache_clear',
                                                                                  'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection.reindex': ('xtras.html#reindexcollection.reindex', 'fastcore/xtras.py'),
                                'fastcore.xtras.ReindexCollection.shuffle': ('xtras.html#reindexcollection.shuffle', 'fastcore/xtras.py'),
                                'fastcore.xtras._ceil': ('xtras.html#_ceil', 'fastcore/xtras.py'),
                                'fastcore.xtras._has_property_getter': ('xtras.html#_has_property_getter', 'fastcore/xtras.py'),
                                'fastcore.xtras._is_property': ('xtras.html#_is_property', 'fastcore/xtras.py'),
                                'fastcore.xtras._is_type_dispatch': ('xtras.html#_is_type_dispatch', 'fastcore/xtras.py'),
                                'fastcore.xtras._property_getter': ('xtras.html#_property_getter', 'fastcore/xtras.py'),
                                'fastcore.xtras._repr_dict': ('xtras.html#_repr_dict', 'fastcore/xtras.py'),
                                'fastcore.xtras._sparkchar': ('xtras.html#_sparkchar', 'fastcore/xtras.py'),
                                'fastcore.xtras._unpack': ('xtras.html#_unpack', 'fastcore/xtras.py'),
                                'fastcore.xtras._unwrapped_func': ('xtras.html#_unwrapped_func', 'fastcore/xtras.py'),
                                'fastcore.xtras._unwrapped_type_dispatch_func': ( 'xtras.html#_unwrapped_type_dispatch_func',
                                                                                  'fastcore/xtras.py'),
                                'fastcore.xtras.autostart': ('xtras.html#autostart', 'fastcore/xtras.py'),
                                'fastcore.xtras.bunzip': ('xtras.html#bunzip', 'fastcore/xtras.py'),
                                'fastcore.xtras.console_help': ('xtras.html#console_help', 'fastcore/xtras.py'),
                                'fastcore.xtras.dict2obj': ('xtras.html#dict2obj', 'fastcore/xtras.py'),
                                'fastcore.xtras.dumps': ('xtras.html#dumps', 'fastcore/xtras.py'),
                                'fastcore.xtras.get_source_link': ('xtras.html#get_source_link', 'fastcore/xtras.py'),
                                'fastcore.xtras.globtastic': ('xtras.html#globtastic', 'fastcore/xtras.py'),
                                'fastcore.xtras.image_size': ('xtras.html#image_size', 'fastcore/xtras.py'),
                                'fastcore.xtras.is_listy': ('xtras.html#is_listy', 'fastcore/xtras.py'),
                                'fastcore.xtras.join_path_file': ('xtras.html#join_path_file', 'fastcore/xtras.py'),
                                'fastcore.xtras.load_pickle': ('xtras.html#load_pickle', 'fastcore/xtras.py'),
                                'fastcore.xtras.loads': ('xtras.html#loads', 'fastcore/xtras.py'),
                                'fastcore.xtras.loads_multi': ('xtras.html#loads_multi', 'fastcore/xtras.py'),
                                'fastcore.xtras.local2utc': ('xtras.html#local2utc', 'fastcore/xtras.py'),
                                'fastcore.xtras.mapped': ('xtras.html#mapped', 'fastcore/xtras.py'),
                                'fastcore.xtras.maybe_open': ('xtras.html#maybe_open', 'fastcore/xtras.py'),
                                'fastcore.xtras.mkdir': ('xtras.html#mkdir', 'fastcore/xtras.py'),
                                'fastcore.xtras.modified_env': ('xtras.html#modified_env', 'fastcore/xtras.py'),
                                'fastcore.xtras.modify_exception': ('xtras.html#modify_exception', 'fastcore/xtras.py'),
                                'fastcore.xtras.obj2dict': ('xtras.html#obj2dict', 'fastcore/xtras.py'),
                                'fastcore.xtras.open_file': ('xtras.html#open_file', 'fastcore/xtras.py'),
                                'fastcore.xtras.partial_format': ('xtras.html#partial_format', 'fastcore/xtras.py'),
                                'fastcore.xtras.repo_details': ('xtras.html#repo_details', 'fastcore/xtras.py'),
                                'fastcore.xtras.repr_dict': ('xtras.html#repr_dict', 'fastcore/xtras.py'),
                                'fastcore.xtras.round_multiple': ('xtras.html#round_multiple', 'fastcore/xtras.py'),
                                'fastcore.xtras.run': ('xtras.html#run', 'fastcore/xtras.py'),
                                'fastcore.xtras.save_pickle': ('xtras.html#save_pickle', 'fastcore/xtras.py'),
                                'fastcore.xtras.set_num_threads': ('xtras.html#set_num_threads', 'fastcore/xtras.py'),
                                'fastcore.xtras.shufflish': ('xtras.html#shufflish', 'fastcore/xtras.py'),
                                'fastcore.xtras.sparkline': ('xtras.html#sparkline', 'fastcore/xtras.py'),
                                'fastcore.xtras.stringfmt_names': ('xtras.html#stringfmt_names', 'fastcore/xtras.py'),
                                'fastcore.xtras.trace': ('xtras.html#trace', 'fastcore/xtras.py'),
                                'fastcore.xtras.truncstr': ('xtras.html#truncstr', 'fastcore/xtras.py'),
                                'fastcore.xtras.untar_dir': ('xtras.html#untar_dir', 'fastcore/xtras.py'),
                                'fastcore.xtras.utc2local': ('xtras.html#utc2local', 'fastcore/xtras.py'),
                                'fastcore.xtras.walk': ('xtras.html#walk', 'fastcore/xtras.py')}}}
